==> isbinaryfile-1.0.0.tgz: package/index.js <==
var fs = require("fs");
var path = require("path");

var max_bytes = 512;

function isBinaryFile(file, callback) {
    var exists = fs.exists || path.exists;
    exists(file, function (exists) {
        if (!exists)
            return callback(null, false);

        fs.open(file, 'r', function(err, descriptor){
            if (err)
                return callback(err);
            var bytes = new Buffer(max_bytes);
            // Read the file with no encoding for raw buffer access.
            fs.read(descriptor, bytes, 0, bytes.length, 0, function(err, size, bytes){
                fs.close(descriptor, function(err2){
                    if (err || err2)
                        return callback(err || err2);
                    return callback(null, isBinaryCheck(size, bytes));
                });
            });
        });
    });
}

function isBinaryFileSync(file) {
    var existsSync = fs.existsSync || path.existsSync;

    var size = 0;
    var bytes;
    if (!existsSync(file))
       return false;
    var descriptor = fs.openSync(file, 'r');
    try {
      bytes = new Buffer(max_bytes);
      size = fs.readSync(descriptor, bytes, 0, bytes.length, 0);
    } finally {
      fs.closeSync(descriptor);
    }
    return isBinaryCheck(size, bytes);
}

function isBinaryCheck (size, bytes) {
    if (size === 0)
        return false;

    var suspicious_bytes = 0;
    var total_bytes = Math.min(size, max_bytes);

    if (size >= 3 && bytes[0] == 0xEF && bytes[1] == 0xBB && bytes[2] == 0xBF) {
        // UTF-8 BOM. This isn't binary.
        return false;
    }

    for (var i = 0; i < total_bytes; i++) {
        if (bytes[i] === 0) { // NULL byte--it's binary!
            return true;
        }
        else if ((bytes[i] < 7 || bytes[i] > 14) && (bytes[i] < 32 || bytes[i] > 127)) {
            // UTF-8 detection
            if (bytes[i] > 191 && bytes[i] < 224 && i + 1 < total_bytes) {
                i++;
                if (bytes[i] < 192) {
                    continue;
                }
            }
            else if (bytes[i] > 223 && bytes[i] < 239 && i + 2 < total_bytes) {
                i++;
                if (bytes[i] < 192 && bytes[i + 1] < 192) {
                    i++;
                    continue;
                }
            }
            suspicious_bytes++;
            // Read at least 32 bytes before making a decision
            if (i > 32 && (suspicious_bytes * 100) / total_bytes > 10) {
                return true;
            }
        }
    }

    if ((suspicious_bytes * 100) / total_bytes > 10) {
        return true;
    }

    return false;
}

exports.isBinaryFile = isBinaryFile;
exports.isBinaryFileSync = isBinaryFileSync;

==> isbinaryfile-1.0.1.tgz: package/index.js <==
var fs = require('fs');

module.exports = function(bytes, size) {
    var max_bytes = 512;

    // Read the file with no encoding for raw buffer access.
    if (size === undefined) {
        var file = bytes;
        if (!fs.existsSync(file))
           return false;
        var descriptor = fs.openSync(file, 'r');
        try {
          bytes = new Buffer(max_bytes);
          size = fs.readSync(descriptor, bytes, 0, bytes.length, 0);
        } finally {
          fs.closeSync(descriptor);
        }
    }

    if (size == 0)
        return false;

    var suspicious_bytes = 0;
    var total_bytes = Math.min(size, max_bytes);

    if (size >= 3 && bytes[0] == 0xEF && bytes[1] == 0xBB && bytes[2] == 0xBF) {
        // UTF-8 BOM. This isn't binary.
        return false;
    }

    for (var i = 0; i < total_bytes; i++) {
        if (bytes[i] == 0) { // NULL byte--it's binary!
            return true;
        }
        else if ((bytes[i] < 7 || bytes[i] > 14) && (bytes[i] < 32 || bytes[i] > 127)) {
            // UTF-8 detection
            if (bytes[i] > 191 && bytes[i] < 224 && i + 1 < total_bytes) {
                i++;
                if (bytes[i] < 192) {
                    continue;
                }
            }
            else if (bytes[i] > 223 && bytes[i] < 239 && i + 2 < total_bytes) {
                i++;
                if (bytes[i] < 192 && bytes[i + 1] < 192) {
                    i++;
                    continue;
                }
            }
            suspicious_bytes++;
            // Read at least 32 bytes before making a decision
            if (i > 32 && (suspicious_bytes * 100) / total_bytes > 10) {
                return true;
            }
        }
    }

    if ((suspicious_bytes * 100) / total_bytes > 10) {
        return true;
    }

    return false;
}
